@@ -55,9 +55,9 @@ config_network(){
     configured_ip_no="$(get-all-nic-ip -i | wc -w)"
     [ "$configured_ip_no" -eq "$eth_port_no" ] && break
     [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
-    echo "Note! You have more than one network cards. Now you can continue to configure them if you want. However, remember those network cards for clients to connect should NOT be assigned with default gateway!"
+    echo $msg_do_not_assign_default_gw_for_DRBL_NIC
     [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
-    echo "Continue to configure another network card ?"
+    echo "$msg_continue_to_conf_another_NIC"
     echo -n "[Y/n] "
     read continue_conf_eth
     case "$continue_conf_eth" in
@@ -68,13 +68,13 @@ config_network(){
   IP_no="$(get-all-nic-ip -i | wc -w)"
   if [ "$IP_no" -eq 0 ]; then
     [ "$BOOTUP" = "color" ] && $SETCOLOR_FAILURE
-    echo "No IP address is configured!"
+    echo $msg_no_ip_address_is_configured
     echo "$msg_program_stop"
     [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
     exit 1
   elif [ "$IP_no" -eq 1 ]; then
     [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
-    echo "Only one IP address, so now creating an alias IP address to be used for DRBL clients..."
+    echo $msg_only_one_IP_so_create_alias_IP
     [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
     alias_done="no"
     i="$private_IP_alias_eth_def"
@@ -98,7 +98,7 @@ NET_END
   else
     # More than one IP address, so it's not necessary to use alias IP address.
     [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
-    echo "There is more than one IP addresses. Those not connected to WAN will be used for DRBL clients."
+    echo $msg_more_than_1_IP_some_for_DRBL_clients
     [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
   fi
 
@@ -123,7 +123,7 @@ case "$switch" in
 
      #
      echo "$msg_delimiter_star_line"
-     echo "Now we will continue to run drblpush to fit the changes."
+     echo $msg_now_continue_to_run_drblpush
      echo $msg_this_might_take_several_minutes
      echo -n $msg_press_enter_to_continue
      read
@@ -131,6 +131,10 @@ case "$switch" in
      # load $client_no_per_NIC
      . /opt/drbl/setup/files/ocs/live-hook/ocs-live.conf
      yes "" | drblpush -i -r 1 -z 1 -p $client_no_per_NIC
+
+     # modify dhcpd.conf, provide IP address to PXE/Etherboot/DRBL client only
+     perl -pi -e 's/^([[:space:]]*)#([[:space:]]*allow members of "DRBL-Client";)/$1 $2/g' /etc/dhcp3/dhcpd.conf
+
      # turn on tcpwrapper
      echo "Setting /etc/hosts.allow..."
      mv -f /etc/hosts.allow /etc/hosts.allow.orig
@@ -152,6 +156,9 @@ case "$switch" in
 
      # set locales for clients.
      set_locale_for_clients
+
+     #
+     echo "$msg_done!"
      ;;
    "stop")
      # block all the clients.
